---
title: control
keywords: documentation
layout: documentation
sidebar: wls_install_sidebar
toc: false
---
## Overview

This defined type allows you to control a admin server or a managed server during s Puppet run. It allows you to stop, start or restart a managed server. Here is an example on how you could use this:

```puppet
ora_install::control{'startWLSAdminServer12c':
  domain_name                 => "Wls12c",
  server_type                 => 'admin',  # admin|managed
  target                      => 'Server', # Server|Cluster
  server                      => 'AdminServer',
  action                      => 'start',
  weblogic_home_dir           => "/opt/oracle/middleware12c/wlserver",
  jdk_home_dir                => "/usr/java/jdk1.7.0_45",
  weblogic_user               => "weblogic",
  weblogic_password           => "weblogic1",
  adminserver_address         => 'localhost',
  adminserver_port            => 7001,
  nodemanager_port            => 5556,
  nodemanager_secure_listener => true,
  os_user                     => "oracle",
  os_group                    => "dba",
  download_dir                => "/data/install",
}
```




## Attributes



Attribute Name                                                      | Short Description                                                                                 |
------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------- |
[action](#control_action)                                           | Action to perform.                                                                                |
[adminserver_address](#control_adminserver_address)                 | The address of the admin server.                                                                  |
[adminserver_port](#control_adminserver_port)                       | The IP port the admin server is listening on.                                                     |
[custom_trust](#control_custom_trust)                               | Determine if you want to use a custom trust or not.                                               |
[domain_name](#control_domain_name)                                 | The domain name.                                                                                  |
[download_dir](#control_download_dir)                               | The directory where the Puppet software puts all downloaded files.                                |
[jdk_home_dir](#control_jdk_home_dir)                               | The homdirectory for the Java evelopment Kit.                                                     |
[jsse_enabled](#control_jsse_enabled)                               | Determine if you want to enable JSSE security.                                                    |
[log_output](#control_log_output)                                   | **DEPRECATED** This parameter is replaced by 'logoutput' and will be removed in a future release. |
[logoutput](#control_logoutput)                                     | log the outputs of Puppet exec or not.                                                            |
[middleware_home_dir](#control_middleware_home_dir)                 | Middleware home directory.                                                                        |
[nodemanager_port](#control_nodemanager_port)                       | The IP port the nodemanager is listening on.                                                      |
[nodemanager_secure_listener](#control_nodemanager_secure_listener) | Use SSL for listening.                                                                            |
[os_group](#control_os_group)                                       | The os group used to install and run WebLogic.                                                    |
[os_user](#control_os_user)                                         | The os user used to install and run WebLogic.                                                     |
[server](#control_server)                                           | Name of the server you want to control.                                                           |
[server_type](#control_server_type)                                 | Type of element you want to control:
                                                             |
[target](#control_target)                                           | Type of target to use:
                                                                           |
[trust_keystore_file](#control_trust_keystore_file)                 | File specificiation of the trust keystore.                                                        |
[trust_keystore_passphrase](#control_trust_keystore_passphrase)     | Passphrase to use for the trust keystore.                                                         |
[weblogic_home_dir](#control_weblogic_home_dir)                     | Directory to use as WebLogic home.                                                                |
[weblogic_password](#control_weblogic_password)                     | The password of the base WebLogic user name.                                                      |
[weblogic_user](#control_weblogic_user)                             | The base WebLogic username to configure.                                                          |
[wls_domains_dir](#control_wls_domains_dir)                         | The root directory where all domain directories reside in.                                        |




### middleware_home_dir<a name='control_middleware_home_dir'>

Middleware home directory.


Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_middleware_home_dir'})`

[Back to overview of control](#attributes)

### weblogic_home_dir<a name='control_weblogic_home_dir'>

Directory to use as WebLogic home.

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_weblogic_home_dir'})`

[Back to overview of control](#attributes)

### jdk_home_dir<a name='control_jdk_home_dir'>

The homdirectory for the Java evelopment Kit.

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_jdk_home_dir'})`

[Back to overview of control](#attributes)

### wls_domains_dir<a name='control_wls_domains_dir'>

The root directory where all domain directories reside in.

Type: `Optional[
    Stdlib::Absolutepath
  ]`

Default:`lookup({name =>'wls_domains_dir', default_value => undef})`

[Back to overview of control](#attributes)

### domain_name<a name='control_domain_name'>

The domain name.

Type: `String[1]`

Default:`lookup({name => 'domain_name'})`

[Back to overview of control](#attributes)

### server_type<a name='control_server_type'>

Type of element you want to control:

Valid values are:

- admin
- managed
- ohs_standalone
 
Type: `Enum[
    'admin',
    'managed',
    'ohs_standalone'
  ]`

Default:`'admin'`

[Back to overview of control](#attributes)

### target<a name='control_target'>

Type of target to use:

Valid values are:

 - Server
 - Cluster

Type: `Enum[
    'Server',
    'Cluster'
  ]`

Default:`'Server'`

[Back to overview of control](#attributes)

### server<a name='control_server'>

Name of the server you want to control.

Type: `String[1]`

Default:`'AdminServer'`

[Back to overview of control](#attributes)

### adminserver_address<a name='control_adminserver_address'>

The address of the admin server. May be a DNS name or a physical IP address.

Type: `String[1]`

Default:`lookup({name => 'domain_adminserver_address', default_value => 'localhost'})`

[Back to overview of control](#attributes)

### adminserver_port<a name='control_adminserver_port'>

The IP port the admin server is listening on.

Type: `Integer`

Default:`lookup({name => 'domain_adminserver_port', default_value => 7001})`

[Back to overview of control](#attributes)

### nodemanager_secure_listener<a name='control_nodemanager_secure_listener'>

Use SSL for listening.

Type: `Boolean`

Default:`true`

[Back to overview of control](#attributes)

### nodemanager_port<a name='control_nodemanager_port'>

The IP port the nodemanager is listening on.

Type: `Integer`

Default:`lookup({name => 'domain_nodemanager_port', default_value => 5556})`

[Back to overview of control](#attributes)

### action<a name='control_action'>

Action to perform. 

Valid values:

- start
- running
- stop
- abort
  
Type: `Enum[
    'start',
    'running',
    'stop',
    'abort'
  ]`

Default:`'start'`

[Back to overview of control](#attributes)

### weblogic_user<a name='control_weblogic_user'>

The base WebLogic username to configure.

Type: `String[1]`

Default:`lookup({name => 'wls_weblogic_user', default_value => 'weblogic'})`

[Back to overview of control](#attributes)

### weblogic_password<a name='control_weblogic_password'>

The password of the base WebLogic user name.

Type: `String[1]`

Default:`lookup({name => 'domain_wls_password'})`

[Back to overview of control](#attributes)

### jsse_enabled<a name='control_jsse_enabled'>

Determine if you want to enable JSSE security.

Type: `Boolean`

Default:`lookup({name => 'wls_jsse_enabled', default_value => false})`

[Back to overview of control](#attributes)

### custom_trust<a name='control_custom_trust'>

Determine if you want to use a custom trust or not.

Type: `Boolean`

Default:`lookup({name => 'wls_custom_trust', default_value => false})`

[Back to overview of control](#attributes)

### trust_keystore_file<a name='control_trust_keystore_file'>

File specificiation of the trust keystore.


Type: `Optional[String[1]]`

Default:`lookup({name => 'wls_trust_keystore_file', default_value => undef})`

[Back to overview of control](#attributes)

### trust_keystore_passphrase<a name='control_trust_keystore_passphrase'>

Passphrase to use for the trust keystore.

Type: `Optional[String[1]]`

Default:`lookup({name => 'wls_trust_keystore_passphrase', default_value => undef})`

[Back to overview of control](#attributes)

### os_user<a name='control_os_user'>

The os user used to install and run WebLogic.


Type: `String[1]`

Default:`lookup({name => 'wls_os_user'})`

[Back to overview of control](#attributes)

### os_group<a name='control_os_group'>

The os group used to install and run WebLogic.


Type: `String[1]`

Default:`lookup({name => 'wls_os_group'})`

[Back to overview of control](#attributes)

### download_dir<a name='control_download_dir'>

The directory where the Puppet software puts all downloaded files.

Before Puppet can actually use remote files, they must be downloaded first. Puppet uses this directory to put all files in.

The default value is: `/install`

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_download_dir'})`

[Back to overview of control](#attributes)

### log_output<a name='control_log_output'>

**DEPRECATED** This parameter is replaced by 'logoutput' and will be removed in a future release.
log the outputs of Puppet exec or not.

When you specify `true` Puppet will log all output of `exec` types.

Valid values are:

- `true`
- `false`
- `on_failure`

Type: `Optional[
    Variant[
      Boolean,
      Enum[
        'on_failure'
      ]
    ]
  ]`

Default:`undef`

[Back to overview of control](#attributes)

### logoutput<a name='control_logoutput'>

log the outputs of Puppet exec or not.

When you specify `true` Puppet will log all output of `exec` types.

Valid values are:

- `true`
- `false`
- `on_failure`

Type: `Variant[
    Boolean,
    Enum[
      'on_failure'
    ]
  ]`

Default:`lookup({name => 'logoutput', default_value => 'on_failure'})`

[Back to overview of control](#attributes)
