---
title: domain
keywords: documentation
layout: documentation
sidebar: wls_install_sidebar
toc: false
---
## Overview

 This defined type allows you create a WebLogic domain. It supports the following WebLogic versions:
- 1036
- 1111
- 1211
- 1212
- 1213

You can specify a domain template, thus specifying what kind of domain will be created. Using the template, you can create a Fusion Middleware enabled domain. The defined type supports the following templates:
- Standard
- Adf
- Osb
- osb_soa
- osb_soa_bpm
- soa
- soa_bpm

Here is an example on how you could use this:

```puppet
orawls::domain { 'wlsDomain12c':
  version                     => 1212
  weblogic_home_dir           => "/opt/oracle/middleware12c/wlserver",
  middleware_home_dir         => "/opt/oracle/middleware12c",
  jdk_home_dir                => "/usr/java/jdk1.7.0_45",
  domain_template             => "standard", 
  domain_name                 => "Wls12c",
  development_mode            => false,
  adminserver_name            => "AdminServer",
  adminserver_address         => "localhost",
  adminserver_port            => 7001,
  nodemanager_secure_listener => true,
  nodemanager_port            => 5556,
  java_arguments              => { "ADM" => "...", "OSB" => "...", "SOA" => "...", "BAM" => "..."},
  weblogic_user               => "weblogic",
  weblogic_password           => "weblogic1",
  os_user                     => "oracle",
  os_group                    => "dba",
  log_dir                     => "/data/logs",
  download_dir                => "/data/install",
}

```




## Attributes



Attribute Name                                                                         | Short Description                                                                                 |
-------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------- |
[adminserver_address](#domain_adminserver_address)                                     | The address of the admin server.                                                                  |
[adminserver_listen_on_all_interfaces](#domain_adminserver_listen_on_all_interfaces)   | Boolean to determine if you want to let the adminserver listen on all interfaces.                 |
[adminserver_machine_name](#domain_adminserver_machine_name)                           | machine name you want to run the adminserver on.                                                  |
[adminserver_name](#domain_adminserver_name)                                           | The name of the Admin Server.                                                                     |
[adminserver_port](#domain_adminserver_port)                                           | The IP port the admin server is listening on.                                                     |
[adminserver_ssl_port](#domain_adminserver_ssl_port)                                   | SSL port to use for the Admin server.                                                             |
[b2b_enabled](#domain_b2b_enabled)                                                     | Boolean to determine if b2b is eanbled.                                                           |
[bam_enabled](#domain_bam_enabled)                                                     | Boolean to determine in BAM is enabled.                                                           |
[create_rcu](#domain_create_rcu)                                                       | Determine if you want to create a RCU for the current domain.                                     |
[custom_identity](#domain_custom_identity)                                             | Determine if you want to use a custom identity store or not.                                      |
[custom_identity_alias](#domain_custom_identity_alias)                                 | Alias for custom identity.                                                                        |
[custom_identity_keystore_filename](#domain_custom_identity_keystore_filename)         | file name of the keystore identity file.                                                          |
[custom_identity_keystore_passphrase](#domain_custom_identity_keystore_passphrase)     | Passphrase to use when opening the identity keystore.                                             |
[custom_identity_privatekey_passphrase](#domain_custom_identity_privatekey_passphrase) | Private passphrase to use when opening the identity keystore.                                     |
[custom_trust](#domain_custom_trust)                                                   | Determine if you want to use a custom trust or not.                                               |
[development_mode](#domain_development_mode)                                           | Boolean to determine if you want to create a development domain.                                  |
[domain_name](#domain_domain_name)                                                     | The domain name.                                                                                  |
[domain_password](#domain_domain_password)                                             | Password to use for the domain.                                                                   |
[domain_template](#domain_domain_template)                                             | Template you want to use for the domain.                                                          |
[download_dir](#domain_download_dir)                                                   | The directory where the Puppet software puts all downloaded files.                                |
[ess_enabled](#domain_ess_enabled)                                                     | Boolean to determine of ESS is enabled for the domain.                                            |
[java_arguments](#domain_java_arguments)                                               | Arguments to use when calling java.                                                               |
[jdk_home_dir](#domain_jdk_home_dir)                                                   | The homdirectory for the Java evelopment Kit.                                                     |
[jdk_major_version](#domain_jdk_major_version)                                         | Major version of JDK to use.                                                                      |
[jsse_enabled](#domain_jsse_enabled)                                                   | Determine if you want to enable JSSE security.                                                    |
[log_dir](#domain_log_dir)                                                             | Directory to use for logging.                                                                     |
[log_output](#domain_log_output)                                                       | **DEPRECATED** This parameter is replaced by 'logoutput' and will be removed in a future release. |
[logoutput](#domain_logoutput)                                                         | log the outputs of Puppet exec or not.                                                            |
[middleware_home_dir](#domain_middleware_home_dir)                                     | Middleware home directory.                                                                        |
[nodemanager_address](#domain_nodemanager_address)                                     | Address the nodemanager is running on.                                                            |
[nodemanager_password](#domain_nodemanager_password)                                   | Password to use for nodemanager.                                                                  |
[nodemanager_port](#domain_nodemanager_port)                                           | The IP port the nodemanager is listening on.                                                      |
[nodemanager_secure_listener](#domain_nodemanager_secure_listener)                     | Use SSL for listening.                                                                            |
[nodemanager_username](#domain_nodemanager_username)                                   | Username to use for nodemananer.                                                                  |
[ohs_standalone_listen_address](#domain_ohs_standalone_listen_address)                 | Listen address for OHS standlone server.                                                          |
[ohs_standalone_listen_port](#domain_ohs_standalone_listen_port)                       | Listen port for OHS standlone server.                                                             |
[ohs_standalone_ssl_listen_port](#domain_ohs_standalone_ssl_listen_port)               | SSL Listen port for OHS standlone server.                                                         |
[os_group](#domain_os_group)                                                           | The os group used to install and run WebLogic.                                                    |
[os_user](#domain_os_user)                                                             | The os user used to install and run WebLogic.                                                     |
[owsm_enabled](#domain_owsm_enabled)                                                   | Boolean to detrmine if owsm is enabled.                                                           |
[puppet_os_user](#domain_puppet_os_user)                                               | The Puppet OS user to use.                                                                        |
[rcu_database_url](#domain_rcu_database_url)                                           | Database URL to create the RCU on.                                                                |
[rcu_honor_omf](#domain_rcu_honor_omf)                                                 | Boolean to determine if you want the RCU creation to honor OMF (Oracle Managed Files).            |
[rcu_soa_profile](#domain_rcu_soa_profile)                                             | Profile to use for creating the RCU for SOA.                                                      |
[repository_database_url](#domain_repository_database_url)                             | The jdbc URL of the RCU repository.                                                               |
[repository_password](#domain_repository_password)                                     | The password to use for accessing the RCU repository.                                             |
[repository_prefix](#domain_repository_prefix)                                         | Extra prefix to use for the RCU.                                                                  |
[repository_sys_password](#domain_repository_sys_password)                             | SYS password to use on the database where the RCU repository is created.                          |
[repository_sys_user](#domain_repository_sys_user)                                     | SYS username to use on the database where the RCU repository is created.                          |
[trust_keystore_file](#domain_trust_keystore_file)                                     | File specificiation of the trust keystore.                                                        |
[trust_keystore_passphrase](#domain_trust_keystore_passphrase)                         | Passphrase to use for the trust keystore.                                                         |
[version](#domain_version)                                                             | The version that is installed in the used Oracle home.                                            |
[weblogic_home_dir](#domain_weblogic_home_dir)                                         | Directory to use as WebLogic home.                                                                |
[weblogic_password](#domain_weblogic_password)                                         | The password of the base WebLogic user name.                                                      |
[weblogic_user](#domain_weblogic_user)                                                 | The base WebLogic username to configure.                                                          |
[webtier_enabled](#domain_webtier_enabled)                                             | Boolean to determine if you want to enable the WebTier.                                           |
[wls_apps_dir](#domain_wls_apps_dir)                                                   | The root directory where all aplication directories reside in.                                    |
[wls_domains_dir](#domain_wls_domains_dir)                                             | The root directory where all domain directories reside in.                                        |
[wls_domains_file](#domain_wls_domains_file)                                           | file containing the current domains available on the system.                                      |




### version<a name='domain_version'>

The version that is installed in the used Oracle home.

Puppet uses this value to decide on version specific actions.

Type: `Wls_install::Versions`

Default:`lookup({name => 'wls_version', default_value => 1111})`

[Back to overview of domain](#attributes)

### weblogic_home_dir<a name='domain_weblogic_home_dir'>

Directory to use as WebLogic home.

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_weblogic_home_dir'})`

[Back to overview of domain](#attributes)

### middleware_home_dir<a name='domain_middleware_home_dir'>

Middleware home directory.


Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_middleware_home_dir'})`

[Back to overview of domain](#attributes)

### jdk_home_dir<a name='domain_jdk_home_dir'>

The homdirectory for the Java evelopment Kit.

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_jdk_home_dir'})`

[Back to overview of domain](#attributes)

### jdk_major_version<a name='domain_jdk_major_version'>

Major version of JDK to use.

Type: `Variant[
    Integer[7,7],
    Integer[8,8]
  ]`

Default:`lookup({name => 'wls_jdk_major_version', default_value => 7})`

[Back to overview of domain](#attributes)

### wls_domains_dir<a name='domain_wls_domains_dir'>

The root directory where all domain directories reside in.

Type: `Optional[Stdlib::Absolutepath]`

Default:`lookup({name => 'wls_domains_dir', default_value => undef})`

[Back to overview of domain](#attributes)

### wls_apps_dir<a name='domain_wls_apps_dir'>

The root directory where all aplication directories reside in.

Type: `Optional[Stdlib::Absolutepath]`

Default:`lookup({name => 'wls_apps_dir', default_value => undef})`

[Back to overview of domain](#attributes)

### domain_template<a name='domain_domain_template'>

Template you want to use for the domain.

Valid values are:

standard
ohs_standalone
adf_restricted
osb
osb_soa
osb_soa_bpm
soa
soa_bpm
bam
adf
oim
oud
wc
wc_wcc_bpm
  
Type: `Enum[
    'standard',
    'ohs_standalone',
    'adf_restricted',
    'osb',
    'osb_soa',
    'osb_soa_bpm',
    'soa',
    'soa_bpm',
    'bam',
    'adf',
    'oim',
    'oud',
    'wc',
    'wc_wcc_bpm',
    'forms'
  ]`

Default:`lookup({name => 'domain_template', default_value => 'standard'})`

[Back to overview of domain](#attributes)

### bam_enabled<a name='domain_bam_enabled'>

Boolean to determine in BAM is enabled.

Type: `Boolean`

Default:`true`

[Back to overview of domain](#attributes)

### b2b_enabled<a name='domain_b2b_enabled'>

Boolean to determine if b2b is eanbled.

Type: `Boolean`

Default:`false`

[Back to overview of domain](#attributes)

### ess_enabled<a name='domain_ess_enabled'>

Boolean to determine of ESS is enabled for the domain.

Type: `Boolean`

Default:`false`

[Back to overview of domain](#attributes)

### owsm_enabled<a name='domain_owsm_enabled'>

Boolean to detrmine if owsm is enabled.

Type: `Boolean`

Default:`false`

[Back to overview of domain](#attributes)

### domain_name<a name='domain_domain_name'>

The domain name.

Type: `String[1]`

Default:`lookup({name => 'domain_name'})`

[Back to overview of domain](#attributes)

### development_mode<a name='domain_development_mode'>

Boolean to determine if you want to create a development domain.

Type: `Boolean`

Default:`true`

[Back to overview of domain](#attributes)

### adminserver_name<a name='domain_adminserver_name'>

The name of the Admin Server.

Type: `String[1]`

Default:`lookup({name => 'domain_adminserver', default_value => 'AdminServer'})`

[Back to overview of domain](#attributes)

### adminserver_machine_name<a name='domain_adminserver_machine_name'>

machine name you want to run the adminserver on.

Type: `String[1]`

Default:`lookup({name => 'domain_adminserver_machine_name', default_value => 'LocalMachine'})`

[Back to overview of domain](#attributes)

### adminserver_address<a name='domain_adminserver_address'>

The address of the admin server. May be a DNS name or a physical IP address.

Type: `String[1]`

Default:`lookup({name => 'domain_adminserver_address', default_value => undef})`

[Back to overview of domain](#attributes)

### adminserver_port<a name='domain_adminserver_port'>

The IP port the admin server is listening on.

Type: `Integer`

Default:`lookup({name => 'domain_adminserver_port', default_value => 7001})`

[Back to overview of domain](#attributes)

### adminserver_ssl_port<a name='domain_adminserver_ssl_port'>

SSL port to use for the Admin server.

Type: `Optional[Integer]`

Default:`undef`

[Back to overview of domain](#attributes)

### adminserver_listen_on_all_interfaces<a name='domain_adminserver_listen_on_all_interfaces'>

Boolean to determine if you want to let the adminserver listen on all interfaces.

Type: `Boolean`

Default:`false`

[Back to overview of domain](#attributes)

### java_arguments<a name='domain_java_arguments'>

Arguments to use when calling java.

Type: `Hash`

Default:`lookup({name => 'domain_java_arguments', default_value => {}})`

[Back to overview of domain](#attributes)

### nodemanager_address<a name='domain_nodemanager_address'>

Address the nodemanager is running on. This may be a DNS name or a physical IP address.

Type: `Optional[String[1]]`

Default:`undef`

[Back to overview of domain](#attributes)

### nodemanager_port<a name='domain_nodemanager_port'>

The IP port the nodemanager is listening on.

Type: `Integer`

Default:`lookup({name => 'domain_nodemanager_port', default_value => 5556})`

[Back to overview of domain](#attributes)

### nodemanager_secure_listener<a name='domain_nodemanager_secure_listener'>

Use SSL for listening.

Type: `Boolean`

Default:`true`

[Back to overview of domain](#attributes)

### weblogic_user<a name='domain_weblogic_user'>

The base WebLogic username to configure.

Type: `String[1]`

Default:`lookup({name => 'wls_weblogic_user', default_value => 'weblogic'})`

[Back to overview of domain](#attributes)

### weblogic_password<a name='domain_weblogic_password'>

The password of the base WebLogic user name.

Type: `String[1]`

Default:`lookup({name => 'domain_wls_password'})`

[Back to overview of domain](#attributes)

### nodemanager_username<a name='domain_nodemanager_username'>

Username to use for nodemananer.

Type: `Optional[String[1]]`

Default:`undef`

[Back to overview of domain](#attributes)

### nodemanager_password<a name='domain_nodemanager_password'>

Password to use for nodemanager.

Type: `Optional[String[1]]`

Default:`undef`

[Back to overview of domain](#attributes)

### domain_password<a name='domain_domain_password'>

Password to use for the domain.

Type: `Optional[String[1]]`

Default:`undef`

[Back to overview of domain](#attributes)

### jsse_enabled<a name='domain_jsse_enabled'>

Determine if you want to enable JSSE security.

Type: `Boolean`

Default:`lookup({name => 'wls_jsse_enabled', default_value => false})`

[Back to overview of domain](#attributes)

### webtier_enabled<a name='domain_webtier_enabled'>

Boolean to determine if you want to enable the WebTier.

Type: `Boolean`

Default:`false`

[Back to overview of domain](#attributes)

### os_user<a name='domain_os_user'>

The os user used to install and run WebLogic.


Type: `String[1]`

Default:`lookup({name => 'wls_os_user'})`

[Back to overview of domain](#attributes)

### os_group<a name='domain_os_group'>

The os group used to install and run WebLogic.


Type: `String[1]`

Default:`lookup({name => 'wls_os_group'})`

[Back to overview of domain](#attributes)

### download_dir<a name='domain_download_dir'>

The directory where the Puppet software puts all downloaded files.

Before Puppet can actually use remote files, they must be downloaded first. Puppet uses this directory to put all files in.

The default value is: `/install`

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_download_dir'})`

[Back to overview of domain](#attributes)

### log_dir<a name='domain_log_dir'>

Directory to use for logging.

Type: `Optional[Stdlib::Absolutepath]`

Default:`lookup({name => 'wls_log_dir', default_value => undef})`

[Back to overview of domain](#attributes)

### repository_database_url<a name='domain_repository_database_url'>

The jdbc URL of the RCU repository.

Type: `Optional[String[1]]`

Default:`lookup({name => 'repository_database_url', default_value => undef})`

[Back to overview of domain](#attributes)

### rcu_database_url<a name='domain_rcu_database_url'>

Database URL to create the RCU on.

Type: `Optional[String[1]]`

Default:`undef`

[Back to overview of domain](#attributes)

### rcu_honor_omf<a name='domain_rcu_honor_omf'>

Boolean to determine if you want the RCU creation to honor OMF (Oracle Managed Files).

Type: `Optional[Boolean]`

Default:`undef`

[Back to overview of domain](#attributes)

### rcu_soa_profile<a name='domain_rcu_soa_profile'>

Profile to use for creating the RCU for SOA.

Type: `Optional[
    Enum[
      'SMALL',
      'MED',
      'LARGE'
    ]
  ]`

Default:`undef`

[Back to overview of domain](#attributes)

### repository_prefix<a name='domain_repository_prefix'>

Extra prefix to use for the RCU.

Type: `String[1]`

Default:`lookup({name => 'repository_prefix', default_value => 'DEV'})`

[Back to overview of domain](#attributes)

### repository_password<a name='domain_repository_password'>

The password to use for accessing the RCU repository.

Type: `String[1]`

Default:`lookup({name => 'repository_password', default_value => 'Welcome01'})`

[Back to overview of domain](#attributes)

### repository_sys_user<a name='domain_repository_sys_user'>

SYS username to use on the database where the RCU repository is created.

Default is 'SYS'SYS username to use on the database where the RCU repository is created.

Default is 'SYS'
Type: `String[1]`

Default:`'sys'`

[Back to overview of domain](#attributes)

### repository_sys_password<a name='domain_repository_sys_password'>

SYS password to use on the database where the RCU repository is created.

Type: `Optional[String[1]]`

Default:`undef`

[Back to overview of domain](#attributes)

### custom_trust<a name='domain_custom_trust'>

Determine if you want to use a custom trust or not.

Type: `Boolean`

Default:`lookup({name => 'wls_custom_trust', default_value => false})`

[Back to overview of domain](#attributes)

### trust_keystore_file<a name='domain_trust_keystore_file'>

File specificiation of the trust keystore.


Type: `Optional[String[1]]`

Default:`lookup({name => 'wls_trust_keystore_file', default_value => undef})`

[Back to overview of domain](#attributes)

### trust_keystore_passphrase<a name='domain_trust_keystore_passphrase'>

Passphrase to use for the trust keystore.

Type: `Optional[String[1]]`

Default:`lookup({name => 'wls_trust_keystore_passphrase', default_value => undef})`

[Back to overview of domain](#attributes)

### custom_identity<a name='domain_custom_identity'>

Determine if you want to use a custom identity store or not.

Type: `Boolean`

Default:`false`

[Back to overview of domain](#attributes)

### custom_identity_keystore_filename<a name='domain_custom_identity_keystore_filename'>

file name of the keystore identity file.

Type: `Optional[String[1]]`

Default:`undef`

[Back to overview of domain](#attributes)

### custom_identity_keystore_passphrase<a name='domain_custom_identity_keystore_passphrase'>

Passphrase to use when opening the identity keystore.

Type: `Optional[String[1]]`

Default:`undef`

[Back to overview of domain](#attributes)

### custom_identity_alias<a name='domain_custom_identity_alias'>

Alias for custom identity.

Type: `Optional[String[1]]`

Default:`undef`

[Back to overview of domain](#attributes)

### custom_identity_privatekey_passphrase<a name='domain_custom_identity_privatekey_passphrase'>

Private passphrase to use when opening the identity keystore.

Type: `Optional[String[1]]`

Default:`undef`

[Back to overview of domain](#attributes)

### create_rcu<a name='domain_create_rcu'>

Determine if you want to create a RCU for the current domain.

Type: `Boolean`

Default:`lookup({name => 'create_rcu', default_value => true})`

[Back to overview of domain](#attributes)

### ohs_standalone_listen_address<a name='domain_ohs_standalone_listen_address'>

Listen address for OHS standlone server.

Type: `Optional[String[1]]`

Default:`undef`

[Back to overview of domain](#attributes)

### ohs_standalone_listen_port<a name='domain_ohs_standalone_listen_port'>

Listen port for OHS standlone server.

Type: `Optional[Integer]`

Default:`undef`

[Back to overview of domain](#attributes)

### ohs_standalone_ssl_listen_port<a name='domain_ohs_standalone_ssl_listen_port'>

SSL Listen port for OHS standlone server.

Type: `Optional[Integer]`

Default:`undef`

[Back to overview of domain](#attributes)

### wls_domains_file<a name='domain_wls_domains_file'>

file containing the current domains available on the system.

Type: `Optional[String[1]]`

Default:`undef`

[Back to overview of domain](#attributes)

### puppet_os_user<a name='domain_puppet_os_user'>

The Puppet OS user to use.

Type: `String[1]`

Default:`'root'`

[Back to overview of domain](#attributes)

### log_output<a name='domain_log_output'>

**DEPRECATED** This parameter is replaced by 'logoutput' and will be removed in a future release.
log the outputs of Puppet exec or not.

When you specify `true` Puppet will log all output of `exec` types.

Valid values are:

- `true`
- `false`
- `on_failure`

Type: `Optional[
    Variant[
      Boolean,
      Enum[
        'on_failure'
      ]
    ]
  ]`

Default:`undef`

[Back to overview of domain](#attributes)

### logoutput<a name='domain_logoutput'>

log the outputs of Puppet exec or not.

When you specify `true` Puppet will log all output of `exec` types.

Valid values are:

- `true`
- `false`
- `on_failure`

Type: `Variant[
    Boolean,
    Enum[
      'on_failure'
    ]
  ]`

Default:`lookup({name => 'logoutput', default_value => 'on_failure'})`

[Back to overview of domain](#attributes)
