---
title: fmwclusterjrf
keywords: documentation
layout: documentation
sidebar: wls_install_sidebar
toc: false
---
## Overview

This defined type allows you to convert an existing cluster into an ADF/JRF cluster. Here is an example on how you could use this:

```
ora_install::utils::fmwclusterjrf { 'WebCluster':
  domain_name          => "adf_domain",
  jrf_target_name      => "WebCluster",
  opss_datasource_name => "opss-data-source",
}

```





## Attributes



Attribute Name                                              | Short Description                                                                                 |
----------------------------------------------------------- | ------------------------------------------------------------------------------------------------- |
[adminserver_address](#fmwclusterjrf_adminserver_address)   | The address of the admin server.                                                                  |
[adminserver_name](#fmwclusterjrf_adminserver_name)         | The name of the Admin Server.                                                                     |
[adminserver_port](#fmwclusterjrf_adminserver_port)         | The IP port the admin server is listening on.                                                     |
[domain_name](#fmwclusterjrf_domain_name)                   | The domain name.                                                                                  |
[download_dir](#fmwclusterjrf_download_dir)                 | The directory where the Puppet software puts all downloaded files.                                |
[jdk_home_dir](#fmwclusterjrf_jdk_home_dir)                 | The homdirectory for the Java evelopment Kit.                                                     |
[jrf_target_name](#fmwclusterjrf_jrf_target_name)           | Target to use for JRF objects.                                                                    |
[log_output](#fmwclusterjrf_log_output)                     | **DEPRECATED** This parameter is replaced by 'logoutput' and will be removed in a future release. |
[logoutput](#fmwclusterjrf_logoutput)                       | log the outputs of Puppet exec or not.                                                            |
[middleware_home_dir](#fmwclusterjrf_middleware_home_dir)   | Middleware home directory.                                                                        |
[nodemanager_port](#fmwclusterjrf_nodemanager_port)         | The IP port the nodemanager is listening on.                                                      |
[opss_datasource_name](#fmwclusterjrf_opss_datasource_name) | Datasource to use OPSS.                                                                           |
[os_group](#fmwclusterjrf_os_group)                         | The os group used to install and run WebLogic.                                                    |
[os_user](#fmwclusterjrf_os_user)                           | The os user used to install and run WebLogic.                                                     |
[version](#fmwclusterjrf_version)                           | The version that is installed in the used Oracle home.                                            |
[weblogic_home_dir](#fmwclusterjrf_weblogic_home_dir)       | Directory to use as WebLogic home.                                                                |
[weblogic_password](#fmwclusterjrf_weblogic_password)       | The password of the base WebLogic user name.                                                      |
[weblogic_user](#fmwclusterjrf_weblogic_user)               | The base WebLogic username to configure.                                                          |
[wls_domains_dir](#fmwclusterjrf_wls_domains_dir)           | The root directory where all domain directories reside in.                                        |




### version<a name='fmwclusterjrf_version'>

The version that is installed in the used Oracle home.

Puppet uses this value to decide on version specific actions.

Type: `Wls_install::Versions`

Default:`lookup({name => 'wls_version', default_value => 1111})`

[Back to overview of fmwclusterjrf](#attributes)

### weblogic_home_dir<a name='fmwclusterjrf_weblogic_home_dir'>

Directory to use as WebLogic home.

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_weblogic_home_dir'})`

[Back to overview of fmwclusterjrf](#attributes)

### middleware_home_dir<a name='fmwclusterjrf_middleware_home_dir'>

Middleware home directory.


Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_middleware_home_dir'})`

[Back to overview of fmwclusterjrf](#attributes)

### jdk_home_dir<a name='fmwclusterjrf_jdk_home_dir'>

The homdirectory for the Java evelopment Kit.

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_jdk_home_dir'})`

[Back to overview of fmwclusterjrf](#attributes)

### domain_name<a name='fmwclusterjrf_domain_name'>

The domain name.

Type: `String[1]`

Default:`lookup({name => 'domain_name'})`

[Back to overview of fmwclusterjrf](#attributes)

### wls_domains_dir<a name='fmwclusterjrf_wls_domains_dir'>

The root directory where all domain directories reside in.

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_domains_dir', default_value => undef})`

[Back to overview of fmwclusterjrf](#attributes)

### adminserver_name<a name='fmwclusterjrf_adminserver_name'>

The name of the Admin Server.

Type: `String[1]`

Default:`lookup({name => 'domain_adminserver', default_value => 'AdminServer'})`

[Back to overview of fmwclusterjrf](#attributes)

### adminserver_address<a name='fmwclusterjrf_adminserver_address'>

The address of the admin server. May be a DNS name or a physical IP address.

Type: `String[1]`

Default:`lookup({name => 'domain_adminserver_address', default_value => 'localhost'})`

[Back to overview of fmwclusterjrf](#attributes)

### adminserver_port<a name='fmwclusterjrf_adminserver_port'>

The IP port the admin server is listening on.

Type: `Integer`

Default:`lookup({name => 'domain_adminserver_port', default_value => 7001})`

[Back to overview of fmwclusterjrf](#attributes)

### nodemanager_port<a name='fmwclusterjrf_nodemanager_port'>

The IP port the nodemanager is listening on.

Type: `Integer`

Default:`lookup({name => 'domain_nodemanager_port', default_value => 5556})`

[Back to overview of fmwclusterjrf](#attributes)

### jrf_target_name<a name='fmwclusterjrf_jrf_target_name'>

Target to use for JRF objects.

Type: `String[1]`

Default:`undef`

[Back to overview of fmwclusterjrf](#attributes)

### opss_datasource_name<a name='fmwclusterjrf_opss_datasource_name'>

Datasource to use OPSS.

Type: `String[1]`

Default:`undef`

[Back to overview of fmwclusterjrf](#attributes)

### weblogic_user<a name='fmwclusterjrf_weblogic_user'>

The base WebLogic username to configure.

Type: `String[1]`

Default:`lookup({name => 'wls_weblogic_user', default_value => 'weblogic'})`

[Back to overview of fmwclusterjrf](#attributes)

### weblogic_password<a name='fmwclusterjrf_weblogic_password'>

The password of the base WebLogic user name.

Type: `String[1]`

Default:`lookup({name => 'domain_wls_password'})`

[Back to overview of fmwclusterjrf](#attributes)

### os_user<a name='fmwclusterjrf_os_user'>

The os user used to install and run WebLogic.


Type: `String[1]`

Default:`lookup({name => 'wls_os_user'})`

[Back to overview of fmwclusterjrf](#attributes)

### os_group<a name='fmwclusterjrf_os_group'>

The os group used to install and run WebLogic.


Type: `String[1]`

Default:`lookup({name => 'wls_os_group'})`

[Back to overview of fmwclusterjrf](#attributes)

### download_dir<a name='fmwclusterjrf_download_dir'>

The directory where the Puppet software puts all downloaded files.

Before Puppet can actually use remote files, they must be downloaded first. Puppet uses this directory to put all files in.

The default value is: `/install`

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_download_dir'})`

[Back to overview of fmwclusterjrf](#attributes)

### logoutput<a name='fmwclusterjrf_logoutput'>

log the outputs of Puppet exec or not.

When you specify `true` Puppet will log all output of `exec` types.

Valid values are:

- `true`
- `false`
- `on_failure`

Type: `Variant[
    Boolean,
    Enum[
      'on_failure'
    ]
  ]`

Default:`lookup({name => 'logoutput', default_value => 'on_failure'})`

[Back to overview of fmwclusterjrf](#attributes)

### log_output<a name='fmwclusterjrf_log_output'>

**DEPRECATED** This parameter is replaced by 'logoutput' and will be removed in a future release.
log the outputs of Puppet exec or not.

When you specify `true` Puppet will log all output of `exec` types.

Valid values are:

- `true`
- `false`
- `on_failure`

Type: `Optional[
    Variant[
      Boolean,
      Enum['on_failure']
    ]
  ]`

Default:`undef`

[Back to overview of fmwclusterjrf](#attributes)
