---
title: fmwlogdir
keywords: documentation
layout: documentation
sidebar: wls_install_sidebar
toc: false
---
## Overview

This defined type allows you change a log folder location of a FMW server. Here is an example on how you could use this:

```puppet
wls_install::fmwlogdir{'AdminServer':
  middleware_home_dir    => "/opt/oracle/middleware11gR1",
  weblogic_user          => "weblogic",
  weblogic_password      => "weblogic1",
  os_user                => "oracle",
  os_group               => "dba",
  download_dir           => "/data/install"
  log_dir                => "/var/log/weblogic"
  adminserver_address    => "localhost",
  adminserver_port       => 7001,
  server                 => "AdminServer",
}
```
```

 



## Attributes



Attribute Name                                        | Short Description                                                                                 |
----------------------------------------------------- | ------------------------------------------------------------------------------------------------- |
[adminserver_address](#fmwlogdir_adminserver_address) | The address of the admin server.                                                                  |
[adminserver_port](#fmwlogdir_adminserver_port)       | The IP port the admin server is listening on.                                                     |
[download_dir](#fmwlogdir_download_dir)               | The directory where the Puppet software puts all downloaded files.                                |
[log_dir](#fmwlogdir_log_dir)                         | Directory to use for logging.                                                                     |
[log_output](#fmwlogdir_log_output)                   | **DEPRECATED** This parameter is replaced by 'logoutput' and will be removed in a future release. |
[logoutput](#fmwlogdir_logoutput)                     | log the outputs of Puppet exec or not.                                                            |
[middleware_home_dir](#fmwlogdir_middleware_home_dir) | Middleware home directory.                                                                        |
[os_group](#fmwlogdir_os_group)                       | The os group used to install and run WebLogic.                                                    |
[os_user](#fmwlogdir_os_user)                         | The os user used to install and run WebLogic.                                                     |
[server](#fmwlogdir_server)                           |                                                                                                   |
[userConfigFile](#fmwlogdir_userConfigFile)           |                                                                                                   |
[userKeyFile](#fmwlogdir_userKeyFile)                 |                                                                                                   |
[user_config_file](#fmwlogdir_user_config_file)       |                                                                                                   |
[user_key_file](#fmwlogdir_user_key_file)             |                                                                                                   |
[weblogic_password](#fmwlogdir_weblogic_password)     | The password of the base WebLogic user name.                                                      |
[weblogic_user](#fmwlogdir_weblogic_user)             | The base WebLogic username to configure.                                                          |




### middleware_home_dir<a name='fmwlogdir_middleware_home_dir'>

Middleware home directory.


Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_middleware_home_dir'})`

[Back to overview of fmwlogdir](#attributes)

### adminserver_address<a name='fmwlogdir_adminserver_address'>

The address of the admin server. May be a DNS name or a physical IP address.

Type: `String[1]`

Default:`lookup({name => 'domain_adminserver_address', default_value => 'localhost'})`

[Back to overview of fmwlogdir](#attributes)

### adminserver_port<a name='fmwlogdir_adminserver_port'>

The IP port the admin server is listening on.

Type: `Integer`

Default:`lookup({name => 'domain_adminserver_port', default_value => 7001})`

[Back to overview of fmwlogdir](#attributes)

### weblogic_user<a name='fmwlogdir_weblogic_user'>

The base WebLogic username to configure.

Type: `String[1]`

Default:`lookup({name => 'wls_weblogic_user', default_value => 'weblogic'})`

[Back to overview of fmwlogdir](#attributes)

### weblogic_password<a name='fmwlogdir_weblogic_password'>

The password of the base WebLogic user name.

Type: `Optional[String[1]]`

Default:`lookup({name => 'domain_wls_password', default_value => undef})`

[Back to overview of fmwlogdir](#attributes)

### user_config_file<a name='fmwlogdir_user_config_file'>


Type: `Optional[String[1]]`

Default:`lookup({name => 'domain_user_config_file', default_value => undef})`

[Back to overview of fmwlogdir](#attributes)

### user_key_file<a name='fmwlogdir_user_key_file'>


Type: `Optional[String[1]]`

Default:`lookup({name => 'domain_user_key_file', default_value => undef})`

[Back to overview of fmwlogdir](#attributes)

### userConfigFile<a name='fmwlogdir_userConfigFile'>


Type: `Optional[String[1]]`

Default:`lookup({name => 'domain_user_config_file', default_value => undef})`

[Back to overview of fmwlogdir](#attributes)

### userKeyFile<a name='fmwlogdir_userKeyFile'>


Type: `Optional[String[1]]`

Default:`lookup({name => 'domain_user_key_file', default_value => undef})`

[Back to overview of fmwlogdir](#attributes)

### os_user<a name='fmwlogdir_os_user'>

The os user used to install and run WebLogic.


Type: `String[1]`

Default:`lookup({name => 'wls_os_user'})`

[Back to overview of fmwlogdir](#attributes)

### os_group<a name='fmwlogdir_os_group'>

The os group used to install and run WebLogic.


Type: `String[1]`

Default:`lookup({name => 'wls_os_group'})`

[Back to overview of fmwlogdir](#attributes)

### download_dir<a name='fmwlogdir_download_dir'>

The directory where the Puppet software puts all downloaded files.

Before Puppet can actually use remote files, they must be downloaded first. Puppet uses this directory to put all files in.

The default value is: `/install`

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_download_dir'})`

[Back to overview of fmwlogdir](#attributes)

### server<a name='fmwlogdir_server'>


Type: `String[1]`

Default:`'AdminServer'`

[Back to overview of fmwlogdir](#attributes)

### log_dir<a name='fmwlogdir_log_dir'>

Directory to use for logging.

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_log_dir', default_value => undef})`

[Back to overview of fmwlogdir](#attributes)

### logoutput<a name='fmwlogdir_logoutput'>

log the outputs of Puppet exec or not.

When you specify `true` Puppet will log all output of `exec` types.

Valid values are:

- `true`
- `false`
- `on_failure`

Type: `Variant[
    Boolean,
    Enum[
      'on_failure'
    ]
  ]`

Default:`lookup({name => 'logoutput', default_value => 'on_failure'})`

[Back to overview of fmwlogdir](#attributes)

### log_output<a name='fmwlogdir_log_output'>

**DEPRECATED** This parameter is replaced by 'logoutput' and will be removed in a future release.
log the outputs of Puppet exec or not.

When you specify `true` Puppet will log all output of `exec` types.

Valid values are:

- `true`
- `false`
- `on_failure`

Type: `Optional[
    Variant[
      Boolean,
      Enum[
        'on_failure'
      ]
    ]
  ]`

Default:`undef`

[Back to overview of fmwlogdir](#attributes)
