---
title: packdomain
keywords: documentation
layout: documentation
sidebar: wls_install_sidebar
toc: false
---
## Overview


This defined type allows you pack the definition of your domain into a file. Using ora_install::copydomain, you can copy it to an other node and create a WebLogic cluster.

Here is an example on how you could use this:

```puppet
ora_install::packdomain{"Wls12c":
  weblogic_home_dir      => "/opt/oracle/middleware12c/wlserver",
  middleware_home_dir    => "/opt/oracle/middleware12c",
  jdk_home_dir           => "/usr/java/jdk1.7.0_45",
  wls_domains_dir        => "/opt/oracle/domains",
  domain_name            => "Wls12c",
  os_user                => "oracle",
  os_group               => "dba",
  download_dir           => "/data/install",
}
```




## Attributes



Attribute Name                                         | Short Description                                                                                 |
------------------------------------------------------ | ------------------------------------------------------------------------------------------------- |
[domain_name](#packdomain_domain_name)                 | The domain name.                                                                                  |
[download_dir](#packdomain_download_dir)               | The directory where the Puppet software puts all downloaded files.                                |
[jdk_home_dir](#packdomain_jdk_home_dir)               | The homdirectory for the Java evelopment Kit.                                                     |
[log_output](#packdomain_log_output)                   | **DEPRECATED** This parameter is replaced by 'logoutput' and will be removed in a future release. |
[logoutput](#packdomain_logoutput)                     | log the outputs of Puppet exec or not.                                                            |
[middleware_home_dir](#packdomain_middleware_home_dir) | Middleware home directory.                                                                        |
[os_group](#packdomain_os_group)                       | The os group used to install and run WebLogic.                                                    |
[os_user](#packdomain_os_user)                         | The os user used to install and run WebLogic.                                                     |
[version](#packdomain_version)                         | The version that is installed in the used Oracle home.                                            |
[weblogic_home_dir](#packdomain_weblogic_home_dir)     | Directory to use as WebLogic home.                                                                |
[wls_domains_dir](#packdomain_wls_domains_dir)         | The root directory where all domain directories reside in.                                        |




### version<a name='packdomain_version'>

The version that is installed in the used Oracle home.

Puppet uses this value to decide on version specific actions.

Type: `Wls_install::Versions`

Default:`lookup({name => 'wls_version', default_value => 1111})`

[Back to overview of packdomain](#attributes)

### weblogic_home_dir<a name='packdomain_weblogic_home_dir'>

Directory to use as WebLogic home.

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_weblogic_home_dir'})`

[Back to overview of packdomain](#attributes)

### middleware_home_dir<a name='packdomain_middleware_home_dir'>

Middleware home directory.


Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_middleware_home_dir'})`

[Back to overview of packdomain](#attributes)

### jdk_home_dir<a name='packdomain_jdk_home_dir'>

The homdirectory for the Java evelopment Kit.

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_jdk_home_dir'})`

[Back to overview of packdomain](#attributes)

### wls_domains_dir<a name='packdomain_wls_domains_dir'>

The root directory where all domain directories reside in.

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_domains_dir', default_value => undef})`

[Back to overview of packdomain](#attributes)

### domain_name<a name='packdomain_domain_name'>

The domain name.

Type: `String[1]`

Default:`lookup({name => 'domain_name'})`

[Back to overview of packdomain](#attributes)

### os_user<a name='packdomain_os_user'>

The os user used to install and run WebLogic.


Type: `String[1]`

Default:`lookup({name => 'wls_os_user'})`

[Back to overview of packdomain](#attributes)

### os_group<a name='packdomain_os_group'>

The os group used to install and run WebLogic.


Type: `String[1]`

Default:`lookup({name => 'wls_os_group'})`

[Back to overview of packdomain](#attributes)

### download_dir<a name='packdomain_download_dir'>

The directory where the Puppet software puts all downloaded files.

Before Puppet can actually use remote files, they must be downloaded first. Puppet uses this directory to put all files in.

The default value is: `/install`

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_download_dir'})`

[Back to overview of packdomain](#attributes)

### logoutput<a name='packdomain_logoutput'>

log the outputs of Puppet exec or not.

When you specify `true` Puppet will log all output of `exec` types.

Valid values are:

- `true`
- `false`
- `on_failure`

Type: `Variant[
    Boolean,
    Enum[
      'on_failure'
    ]
  ]`

Default:`lookup({name => 'logoutput', default_value => 'on_failure'})`

[Back to overview of packdomain](#attributes)

### log_output<a name='packdomain_log_output'>

**DEPRECATED** This parameter is replaced by 'logoutput' and will be removed in a future release.
log the outputs of Puppet exec or not.

When you specify `true` Puppet will log all output of `exec` types.

Valid values are:

- `true`
- `false`
- `on_failure`

Type: `Optional[
    Variant[
      Boolean,
      Enum[
        'on_failure'
      ]
    ]
  ]`

Default:`undef`

[Back to overview of packdomain](#attributes)
