---
title: software version
keywords: documentation
layout: documentation
sidebar: wls_install_sidebar
toc: false
---
## Overview

This cdefined tpe allows you install the WebLogic software on your system. You can use this to install multiple versions on your system.

Here is an example on how you could use this:

```
ora_install::software_version{'1221':
  version              => 1221,                       # 1036|1211|1212|1213|1221
  filename             => 'fmw_12.2.1.0.0_wls.jar',   # 
  jdk_home_dir         => '/usr/java/jdk1.8.0_45',
  oracle_base_home_dir => "/opt/oracle",
  middleware_home_dir  => "/opt/oracle/middleware12c",
  weblogic_home_dir    => "/opt/oracle/middleware12c/wlserver",
  os_user              => "oracle",
  os_group             => "dba",
  download_dir         => "/data/install",
  source               => "/vagrant",                 # puppet:///modules/orawls/ | /mnt |
  log_output           => true,
}
```





## Attributes



Attribute Name                                                 | Short Description                                                                                 |
-------------------------------------------------------------- | ------------------------------------------------------------------------------------------------- |
[download_dir](#software_version_download_dir)                 | The directory where the Puppet software puts all downloaded files.                                |
[filename](#software_version_filename)                         | The source file to use.                                                                           |
[fmw_infra](#software_version_fmw_infra)                       | Determine if you want to install Fusion Middleware infra.                                         |
[java_parameters](#software_version_java_parameters)           | The (extra) parameters to pass when calling java.                                                 |
[jdk_home_dir](#software_version_jdk_home_dir)                 | The homdirectory for the Java evelopment Kit.                                                     |
[log_output](#software_version_log_output)                     | **DEPRECATED** This parameter is replaced by 'logoutput' and will be removed in a future release. |
[logoutput](#software_version_logoutput)                       | log the outputs of Puppet exec or not.                                                            |
[middleware_home_dir](#software_version_middleware_home_dir)   | Middleware home directory.                                                                        |
[oracle_base_home_dir](#software_version_oracle_base_home_dir) | A directory to use as Oracle base directory.                                                      |
[os_group](#software_version_os_group)                         | The os group used to install and run WebLogic.                                                    |
[os_user](#software_version_os_user)                           | The os user used to install and run WebLogic.                                                     |
[remote_file](#software_version_remote_file)                   | This parameter is not being used anymore and will be removed in a future release.                 |
[source](#software_version_source)                             | Source for the operation.                                                                         |
[temp_directory](#software_version_temp_directory)             | Directory to use for temporary files.                                                             |
[version](#software_version_version)                           | The version that is installed in the used Oracle home.                                            |
[weblogic_home_dir](#software_version_weblogic_home_dir)       | Directory to use as WebLogic home.                                                                |
[wls_apps_dir](#software_version_wls_apps_dir)                 | The root directory where all aplication directories reside in.                                    |
[wls_domains_dir](#software_version_wls_domains_dir)           | The root directory where all domain directories reside in.                                        |




### version<a name='software_version_version'>

The version that is installed in the used Oracle home.

Puppet uses this value to decide on version specific actions.

Type: `Wls_install::Versions`

Default:`1111`

[Back to overview of software_version](#attributes)

### filename<a name='software_version_filename'>

The source file to use.


Type: `String[1]`

Default:`undef`

[Back to overview of software_version](#attributes)

### oracle_base_home_dir<a name='software_version_oracle_base_home_dir'>

A directory to use as Oracle base directory.


Type: `Stdlib::Absolutepath`

Default:`undef`

[Back to overview of software_version](#attributes)

### middleware_home_dir<a name='software_version_middleware_home_dir'>

Middleware home directory.


Type: `Stdlib::Absolutepath`

Default:`undef`

[Back to overview of software_version](#attributes)

### weblogic_home_dir<a name='software_version_weblogic_home_dir'>

Directory to use as WebLogic home.

Type: `Optional[Stdlib::Absolutepath]`

Default:`undef`

[Back to overview of software_version](#attributes)

### wls_domains_dir<a name='software_version_wls_domains_dir'>

The root directory where all domain directories reside in.

Type: `Optional[Stdlib::Absolutepath]`

Default:`undef`

[Back to overview of software_version](#attributes)

### wls_apps_dir<a name='software_version_wls_apps_dir'>

The root directory where all aplication directories reside in.

Type: `Optional[Stdlib::Absolutepath]`

Default:`undef`

[Back to overview of software_version](#attributes)

### fmw_infra<a name='software_version_fmw_infra'>

Determine if you want to install Fusion Middleware infra.



Type: `Boolean`

Default:`false`

[Back to overview of software_version](#attributes)

### jdk_home_dir<a name='software_version_jdk_home_dir'>

The homdirectory for the Java evelopment Kit.

Type: `Stdlib::Absolutepath`

Default:`undef`

[Back to overview of software_version](#attributes)

### os_user<a name='software_version_os_user'>

The os user used to install and run WebLogic.


Type: `String[1]`

Default:`undef`

[Back to overview of software_version](#attributes)

### os_group<a name='software_version_os_group'>

The os group used to install and run WebLogic.


Type: `String[1]`

Default:`undef`

[Back to overview of software_version](#attributes)

### download_dir<a name='software_version_download_dir'>

The directory where the Puppet software puts all downloaded files.

Before Puppet can actually use remote files, they must be downloaded first. Puppet uses this directory to put all files in.

The default value is: `/install`

Type: `Stdlib::Absolutepath`

Default:`undef`

[Back to overview of software_version](#attributes)

### source<a name='software_version_source'>

Source for the operation.

Type: `String[1]`

Default:`undef`

[Back to overview of software_version](#attributes)

### java_parameters<a name='software_version_java_parameters'>

The (extra) parameters to pass when calling java.

Type: `Optional[String]`

Default:`''`

[Back to overview of software_version](#attributes)

### temp_directory<a name='software_version_temp_directory'>

Directory to use for temporary files.


Type: `Stdlib::Absolutepath`

Default:`'/tmp'`

[Back to overview of software_version](#attributes)

### logoutput<a name='software_version_logoutput'>

log the outputs of Puppet exec or not.

When you specify `true` Puppet will log all output of `exec` types.

Valid values are:

- `true`
- `false`
- `on_failure`

Type: `Variant[
    Boolean,
    Enum[
      'on_failure'
    ]
  ]`

Default:`lookup({name => 'logoutput', default_value => 'on_failure'})`

[Back to overview of software_version](#attributes)

### log_output<a name='software_version_log_output'>

**DEPRECATED** This parameter is replaced by 'logoutput' and will be removed in a future release.
log the outputs of Puppet exec or not.

When you specify `true` Puppet will log all output of `exec` types.

Valid values are:

- `true`
- `false`
- `on_failure`

Type: `Optional[
    Variant[
      Boolean,
      Enum[
        'on_failure'
      ]
    ]
  ]`

Default:`undef`

[Back to overview of software_version](#attributes)

### remote_file<a name='software_version_remote_file'>

**DEPRECATED**
This parameter is not being used anymore and will be removed in a future release.

`true`.

Type: `Optional[Boolean]`

Default:`undef`

[Back to overview of software_version](#attributes)
