---
title: storeuserconfig
keywords: documentation
layout: documentation
sidebar: wls_install_sidebar
toc: false
---
## Overview

This defined type allows you to create a user config for WLST , this way you don't need to know the weblogic password. Here is an example on how you could use this:

```puppet
ora_install::storeuserconfig{'Wls12c':
  domain_name                => "Wls12c",
  adminserver_address        => "localhost",
  adminserver_port           => 7001,
  weblogic_password          => "weblogic1",
  user_config_dir            => '/home/oracle',
  log_output                 => false,
}
```




## Attributes



Attribute Name                                              | Short Description                                                                                 |
----------------------------------------------------------- | ------------------------------------------------------------------------------------------------- |
[adminserver_address](#storeuserconfig_adminserver_address) | The address of the admin server.                                                                  |
[adminserver_port](#storeuserconfig_adminserver_port)       | The IP port the admin server is listening on.                                                     |
[domain_name](#storeuserconfig_domain_name)                 | The domain name.                                                                                  |
[download_dir](#storeuserconfig_download_dir)               | The directory where the Puppet software puts all downloaded files.                                |
[jdk_home_dir](#storeuserconfig_jdk_home_dir)               | The homdirectory for the Java evelopment Kit.                                                     |
[log_output](#storeuserconfig_log_output)                   | **DEPRECATED** This parameter is replaced by 'logoutput' and will be removed in a future release. |
[logoutput](#storeuserconfig_logoutput)                     | log the outputs of Puppet exec or not.                                                            |
[os_group](#storeuserconfig_os_group)                       | The os group used to install and run WebLogic.                                                    |
[os_user](#storeuserconfig_os_user)                         | The os user used to install and run WebLogic.                                                     |
[remote_file](#storeuserconfig_remote_file)                 | This parameter is not being used anymore and will be removed in a future release.                 |
[user_config_dir](#storeuserconfig_user_config_dir)         | Directory where to store the user configs.                                                        |
[weblogic_home_dir](#storeuserconfig_weblogic_home_dir)     | Directory to use as WebLogic home.                                                                |
[weblogic_password](#storeuserconfig_weblogic_password)     | The password of the base WebLogic user name.                                                      |
[weblogic_user](#storeuserconfig_weblogic_user)             | The base WebLogic username to configure.                                                          |




### domain_name<a name='storeuserconfig_domain_name'>

The domain name.

Type: `String[1]`

Default:`lookup({name => 'domain_name'})`

[Back to overview of storeuserconfig](#attributes)

### weblogic_home_dir<a name='storeuserconfig_weblogic_home_dir'>

Directory to use as WebLogic home.

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_weblogic_home_dir'})`

[Back to overview of storeuserconfig](#attributes)

### jdk_home_dir<a name='storeuserconfig_jdk_home_dir'>

The homdirectory for the Java evelopment Kit.

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_jdk_home_dir'})`

[Back to overview of storeuserconfig](#attributes)

### adminserver_address<a name='storeuserconfig_adminserver_address'>

The address of the admin server. May be a DNS name or a physical IP address.

Type: `String[1]`

Default:`lookup({name => 'domain_adminserver_address', default_value => 'localhost'})`

[Back to overview of storeuserconfig](#attributes)

### adminserver_port<a name='storeuserconfig_adminserver_port'>

The IP port the admin server is listening on.

Type: `Integer`

Default:`lookup({name => 'domain_adminserver_port', default_value => 7001})`

[Back to overview of storeuserconfig](#attributes)

### user_config_dir<a name='storeuserconfig_user_config_dir'>

Directory where to store the user configs.

Type: `Stdlib::Absolutepath`

Default:`undef`

[Back to overview of storeuserconfig](#attributes)

### weblogic_user<a name='storeuserconfig_weblogic_user'>

The base WebLogic username to configure.

Type: `String[1]`

Default:`lookup({name => 'wls_weblogic_user', default_value => 'weblogic'})`

[Back to overview of storeuserconfig](#attributes)

### weblogic_password<a name='storeuserconfig_weblogic_password'>

The password of the base WebLogic user name.

Type: `String[1]`

Default:`lookup({name => 'domain_wls_password'})`

[Back to overview of storeuserconfig](#attributes)

### os_user<a name='storeuserconfig_os_user'>

The os user used to install and run WebLogic.


Type: `String[1]`

Default:`lookup({name => 'wls_os_user'})`

[Back to overview of storeuserconfig](#attributes)

### os_group<a name='storeuserconfig_os_group'>

The os group used to install and run WebLogic.


Type: `String[1]`

Default:`lookup({name => 'wls_os_group'})`

[Back to overview of storeuserconfig](#attributes)

### download_dir<a name='storeuserconfig_download_dir'>

The directory where the Puppet software puts all downloaded files.

Before Puppet can actually use remote files, they must be downloaded first. Puppet uses this directory to put all files in.

The default value is: `/install`

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_download_dir'})`

[Back to overview of storeuserconfig](#attributes)

### logoutput<a name='storeuserconfig_logoutput'>

log the outputs of Puppet exec or not.

When you specify `true` Puppet will log all output of `exec` types.

Valid values are:

- `true`
- `false`
- `on_failure`

Type: `Variant[
    Boolean,
    Enum[
      'on_failure'
    ]
  ]`

Default:`lookup({name => 'logoutput', default_value => 'on_failure'})`

[Back to overview of storeuserconfig](#attributes)

### log_output<a name='storeuserconfig_log_output'>

**DEPRECATED** This parameter is replaced by 'logoutput' and will be removed in a future release.
log the outputs of Puppet exec or not.

When you specify `true` Puppet will log all output of `exec` types.

Valid values are:

- `true`
- `false`
- `on_failure`

Type: `Optional[
    Variant[
      Boolean,
      Enum[
        'on_failure'
      ]
    ]
  ]`

Default:`undef`

[Back to overview of storeuserconfig](#attributes)

### remote_file<a name='storeuserconfig_remote_file'>

**DEPRECATED**
This parameter is not being used anymore and will be removed in a future release.

`true`.

Type: `Optional[Boolean]`

Default:`undef`

[Back to overview of storeuserconfig](#attributes)
