#
# See the file "LICENSE" for the full license governing this code.
#
#
#
#
class wls_install::support::files(
  Stdlib::Absolutepath $os_oracle_home            = $wls_install::support::params::osOracleHome,
  Stdlib::Absolutepath $ora_inventory             = $wls_install::support::params::oraInventory,
  String[1]            $os_domain_type            = $wls_install::support::params::osDomainType,
  Stdlib::Absolutepath $os_log_folder             = $wls_install::support::params::osLogFolder,
  Stdlib::Absolutepath $os_download_folder        = $wls_install::support::params::osDownloadFolder,
  Stdlib::Absolutepath $os_mdw_home               = $wls_install::support::params::osMdwHome,
  Stdlib::Absolutepath $os_wl_home                = $wls_install::support::params::osWlHome,
  String[1]            $ora_user                  = $wls_install::support::params::oraUser,
  String[1]            $ora_group                 = $wls_install::support::params::oraGroup,
  String[1]            $os_domain                 = $wls_install::support::params::osDomain,
  Stdlib::Absolutepath $os_domain_path            = $wls_install::support::params::osDomainPath,
  Stdlib::Absolutepath $node_mgr_path             = $wls_install::support::params::nodeMgrPath,
  Integer              $node_mgr_port             = $wls_install::support::params::nodeMgrPort,
  String[1]            $node_mgr_address          = $wls_install::support::params::nodeMgrAddress,
  String[1]            $wls_user                  = $wls_install::support::params::wlsUser,
  String[1]            $wls_password              = $wls_install::support::params::wlsPassword,
  String[1]            $wls_adminserver           = $wls_install::support::params::wlsAdminServer,
  Boolean              $jsse_enabled              = $wls_install::support::params::jsseEnabled,
  Boolean              $custom_trust              = false,
  Optional[String[1]]  $trust_keystore_file       = undef,
  Optional[String[1]]  $trust_keystore_passphrase = undef,
) inherits wls_install::support::params
{
  $root_group = lookup('wls_install::root_group', String[1])

  case $::kernel {
    'Linux', 'SunOS', 'AIX': {

    $mode = '0775'

    $shell = $wls_install::support::params::shell
    $userHome = $wls_install::support::params::userHome
    $oraInstHome = $wls_install::support::params::oraInstHome

    # lint:ignore:140chars
    if ( $custom_trust ) {
      $trust_env = "-Dweblogic.security.TrustKeyStore=CustomTrust -Dweblogic.security.CustomTrustKeyStoreFileName=${trust_keystore_file} -Dweblogic.security.CustomTrustKeystorePassPhrase=${trust_keystore_passphrase}"
    } else {
      $trust_env = ''
    }
    # lint:endignore

    unless ( defined(File['/opt/scripts']) ) {
      file { '/opt/scripts':
        ensure => directory,
        owner  => $ora_user,
        group  => $ora_group,
        mode   => $mode,
      }
    }

    unless ( defined(File['/opt/scripts/wls']) ) {
      file { '/opt/scripts/wls':
        ensure  => directory,
        owner   => $ora_user,
        group   => $ora_group,
        mode    => $mode,
        require => File['/opt/scripts'],
      }
    }

    file { 'showStatus.sh':
      ensure  => present,
      path    => '/opt/scripts/wls/showStatus.sh',
      content => regsubst(template('wls_install/wls/showStatus.sh.erb'), '\r\n', "\n", 'EMG'),
      owner   => $ora_user,
      group   => $ora_group,
      mode    => $mode,
      require => File['/opt/scripts/wls'],
    }

    file { 'stopNodeManager.sh':
      ensure  => present,
      path    => '/opt/scripts/wls/stopNodeManager.sh',
      content => regsubst(template('wls_install/wls/stopNodeManager.sh.erb'), '\r\n', "\n", 'EMG'),
      owner   => $ora_user,
      group   => $ora_group,
      mode    => $mode,
      require => File['/opt/scripts/wls'],
    }

    file { 'cleanOracleEnvironment.sh':
      ensure  => present,
      path    => '/opt/scripts/wls/cleanOracleEnvironment.sh',
      content => regsubst(template('wls_install/cleanOracleEnvironment.sh.erb'), '\r\n', "\n", 'EMG'),
      owner   => 'root',
      group   => $root_group,
      mode    => '0770',
      require => File['/opt/scripts/wls'],
    }

    file { 'startNodeManager.sh':
      ensure  => present,
      path    => '/opt/scripts/wls/startNodeManager.sh',
      content => regsubst(template('wls_install/startNodeManager.sh.erb'), '\r\n', "\n", 'EMG'),
      owner   => $ora_user,
      group   => $ora_group,
      mode    => $mode,
      require => File['/opt/scripts/wls'],
    }

    file { 'startWeblogicAdmin.sh':
      ensure  => present,
      path    => '/opt/scripts/wls/startWeblogicAdmin.sh',
      content => regsubst(template('wls_install/startWeblogicAdmin.sh.erb'), '\r\n', "\n", 'EMG'),
      owner   => $ora_user,
      group   => $ora_group,
      mode    => $mode,
      require => File['/opt/scripts/wls'],
    }

    file { 'stopWeblogicAdmin.sh':
      ensure  => present,
      path    => '/opt/scripts/wls/stopWeblogicAdmin.sh',
      content => regsubst(template('wls_install/stopWeblogicAdmin.sh.erb'), '\r\n', "\n", 'EMG'),
      owner   => $ora_user,
      group   => $ora_group,
      mode    => $mode,
      require => File['/opt/scripts/wls'],
    }

    }
    default: {
      notify{'This operating system is not supported':}
    }
  }
}
